@@ -30,8 +30,7 @@ Usage::
 from datetime import datetime
 from typing import Generic, Iterator, TypeVar, Union
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     ListChannelsResponseTypeDef,
@@ -61,7 +60,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListChannelsPaginator(Boto3Paginator):
+class ListChannelsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators/#listchannelspaginator)
@@ -76,7 +75,7 @@ class ListChannelsPaginator(Boto3Paginator):
         """
 
 
-class ListDatasetContentsPaginator(Boto3Paginator):
+class ListDatasetContentsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators/#listdatasetcontentspaginator)
@@ -96,7 +95,7 @@ class ListDatasetContentsPaginator(Boto3Paginator):
         """
 
 
-class ListDatasetsPaginator(Boto3Paginator):
+class ListDatasetsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators/#listdatasetspaginator)
@@ -111,7 +110,7 @@ class ListDatasetsPaginator(Boto3Paginator):
         """
 
 
-class ListDatastoresPaginator(Boto3Paginator):
+class ListDatastoresPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators/#listdatastorespaginator)
@@ -126,7 +125,7 @@ class ListDatastoresPaginator(Boto3Paginator):
         """
 
 
-class ListPipelinesPaginator(Boto3Paginator):
+class ListPipelinesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators/#listpipelinespaginator)
